Installation
============

This document will guide you through the process of installing the ``metasyn`` package. 

.. note:: 
	If you're new to Python or simply want to quickly explore the basic features of ``metasyn`` without installing it locally, you can try one of our :doc:`/tutorials`.


Step 1: Install Python
----------------------

Metasyn requires Python 3.10 or higher. If you don't have Python installed or your Python version is lower than 3.10, you will need to install or upgrade Python.
If you're not familiar with Python or you've never installed it before, refer to the `Python Guide <https://docs.python-guide.org/starting/installation/>`_ for detailed instructions. 
The Python installation will most likely install `pip`, but if not refer to the `Pip Installation Guide <https://pip.pypa.io/en/stable/installation/>`_ for instructions.

Step 2: Install metasyn
-----------------------

Install metasyn from the command prompt or terminal with:

	.. code-block:: console

		pip install metasyn


Step 3: Verify installation
---------------------------

To ensure ``metasyn`` has been successfully installed, run the following command in a Python console:

.. code-block:: python

	import metasyn

If the command runs without any errors, you have successfully installed metasyn.
